# nmk - next-gen make-like build system

**`nmk`** is an alternative build system, designed following these simple requirements:
* both multi-platform and easy install - available as a python module
* shareable/reusable/factorized build logic between projects

## Documentation

For the full **`nmk`** documentation, see https://github.com/dynod/nmk/wiki
